import * as Ast from "../ast-types";
import { MacroInfoRecord } from "../ast-types";
/**
 * Recursively search for and attach the arguments for a
 * particular macro to its AST node. `macroInfo` should
 * contain a `signature` property which specifies the arguments
 * signature in xparse syntax.
 *
 * @param {object} ast
 * @param {string} macroName
 * @param {object} macroInfo
 * @returns - a new AST
 */
export declare function attachMacroArgs<T extends Ast.Ast>(ast: T, macros: {
    [macroName: string]: {
        signature?: string;
        renderInfo?: object;
    };
}): T;
/**
 * Search (in a right-associative way) through the array for instances of
 * `macroName` and attach arguments to the macro. Argument signatures are
 * specified by `macroInfo.signature`.
 *
 * Info stored in `macroInfo.renderInfo` will be attached to the node
 * with attribute `_renderInfo`.
 */
export declare function attachMacroArgsInArray(ast: Ast.Node[], macros: MacroInfoRecord): Ast.Node[];
/**
 * Search from the start of an array and pick off any arguments matching the passed-in
 * argspec string.
 *
 * @param {[object]} ast
 * @param {string} macroName
 * @param {object} macroInfo
 * @returns {[object]}
 */
export declare function getArgsInArray(ast: Ast.Node[], signature: string): {
    arguments: Ast.Argument[];
    rest: Ast.Node[];
};
/**
 * Extract the contents of a macro's arguments. If an argument was omitted (e.g.,
 * because it was an optional arg that wasn't included), then `null` is returned.
 */
export declare function argContentsFromMacro(macro: Ast.Macro | Ast.Environment): (Ast.Node[] | null)[];
