import { VisitorContext } from "@unified-latex/unified-latex-util-visit";
import * as Ast from "@unified-latex/unified-latex-types";
interface WalkAstOptions {
    triggerTime?: "early" | "late";
    context?: VisitorContext;
}
/**
 * Walk the AST and replace a node with `callback(node)` whenever
 * `callbackTrigger(node)` returns true.
 *
 * @param {object} ast
 * @param {function} callback
 * @param {function} [matcher=() => false]
 * @param {{triggerTime: string}} - "early" indicates that `callback` is called before `walkAst` recurses down the tree. "late" calls `callback` after it has recursed.
 * @returns {object}
 */
export declare function walkAst<T extends Ast.Ast>(ast: Ast.Ast, callback: (ast: T, context?: VisitorContext) => T extends Ast.Node ? Ast.Node : T, matcher?: (node: any, context?: VisitorContext) => node is T, options?: WalkAstOptions): Ast.Ast;
/**
 * Walk through the AST and replace each node matched by `matcher` with `replacer`.
 * `replacer` receives as its first argument the node that was matched and may
 * return a node or an array of nodes.
 *
 * `replacer` can remove an element entirely by returning an empty array or null
 */
export declare function replaceNode(ast: Ast.Ast, replacer: (node: Ast.Node, context?: VisitorContext) => Ast.Node | Ast.Node[] | null, matcher: (node: Ast.Node, context?: VisitorContext) => boolean, options?: WalkAstOptions): Ast.Ast;
export {};
