import { decorateArrayForPegjs } from "@unified-latex/unified-latex-util-pegjs";
import { arrayJoin, splitOnCondition, splitOnMacro, unsplitOnMacro } from "@unified-latex/unified-latex-util-split";
import { trimRenderInfo, match, trim, processEnvironment } from "./ast";
import * as Ast from "./ast-types";
export { trimRenderInfo, match, trim, processEnvironment };
/**
 * Returns true if a `\documentclass` macro is detected,
 * which would indicate that the node list contains the preamble.
 *
 * @param {[object]} nodes
 */
export declare function hasPreambleCode(nodes: Ast.Node[]): boolean;
export { splitOnMacro };
export { splitOnCondition };
export { unsplitOnMacro };
export { arrayJoin };
/**
 * Remove any whitespace from the start and end of environment bodies.
 *
 * @param {*} ast
 * @returns
 */
export declare function trimEnvironmentContents<T extends Ast.Ast>(ast: T): T;
/**
 * Generate a data structure that can be queried
 * for the next/previous node. This allows for "peeking"
 * during the rendering process.
 *
 * @class ReferenceMap
 */
export declare class ReferenceMap {
    ast: Ast.Ast;
    map: Map<Ast.Ast, {
        previous?: Ast.Ast;
        next?: Ast.Ast;
        renderCache?: any;
    }>;
    constructor(ast: Ast.Ast);
    /**
     * Associate render-specific data with this node. This data
     * will be overwritten if `setRenderCache` is called twice.
     *
     * @param {Ast.Ast} node
     * @param {*} data
     * @memberof ReferenceMap
     */
    setRenderCache(node: any, data: any): void;
    /**
     * Retrieve data associated with `node` via `setRenderCache`
     *
     * @param {Ast.Ast} node
     * @returns {(object | undefined)}
     * @memberof ReferenceMap
     */
    getRenderCache(node: any): object | any[] | undefined;
    getPreviousNode(node: Ast.Ast): Ast.Node | undefined;
    getNextNode(node: Ast.Ast): Ast.Node | undefined;
}
export declare function zip<T, U>(array1: T[], array2: U[]): [T, U][];
export { decorateArrayForPegjs };
